MessageParams class

The MessageParams class is used to configure the request to the messages endpoint.

Implemented types

Constructors

MessageParams(String from, List<String> to, String subject, MessageContent content, {List<String>? cc, List<String>? bcc, List<String>? tags, List<File>? attachments, List<String>? inline, MessageOptions? options})

Properties

attachments ↔ List<File>?
getter/setter pair
bcc ↔ List<String>?
getter/setter pair
cc ↔ List<String>?
getter/setter pair
content ↔ MessageContent
Instance of the MessageContent class.
getter/setter pair
from ↔ String
The name and email address of the sender.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inline ↔ List<String>?
getter/setter pair
options ↔ MessageOptions?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subject ↔ String
getter/setter pair
tags ↔ List<String>?
getter/setter pair
to ↔ List<String>
List of recipients.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toRequest(MultipartRequest request) → Future<MultipartRequest>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited