Response class

Response is the class returned by all the clients.

It contains the result of the request and some helper methods.

Constructors

Response(Object result)

Properties

body → Future<Map<String, dynamic>>?
body returns the body of the response as a Map<String, dynamic>.
no setter
hashCode → int
The hash code for this object.
no setterinherited
reasonPhrase → String?
no setter
result ↔ Object
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
ok() → bool
status() → ResponseStatus
status returns the status code and reason phrase of the response as a ResponseStatus object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited